@@ -86,6 +86,7 @@ public:
     bool isIce; /*!< Flag, true if user choose ice tool. */
     bool isModified; /*!< Flag, true if current image is modified and not saved. */
     bool activated;
+    bool bg_mode;
 
     int currentEffect;
 
@@ -193,8 +194,9 @@ private slots:
     void showContextMenu();
     void rollHandler();
     void changeModeByShaking();
-    void changeState(const QString &);
    
+public slots:
+    void changeState(const QString &);
 
 signals:
     void disableAccelerometer();
