@@ -50,6 +50,7 @@ MainWindow::MainWindow(QWidget *parent) :
     createMenus();
 
     this->setStyleSheet("QToolBar {background: black; spacing: 1px}");
+    setContextMenuPolicy(Qt::NoContextMenu);
     ui->toolBar->addAction(brushAct);
     ui->toolBar->addAction(colorToolAct);
     ui->toolBar->addAction(eraserAct);
@@ -59,6 +60,7 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(errorHandler, SIGNAL(accFatalError()), SLOT(disableAccelerometer()));
     connect(painter, SIGNAL(disableAccelerometer()), SLOT(disableAccelerometer()));
     connect(painter, SIGNAL(activateAccelerometer()), SLOT(activateAccelerometer()));
+    connect(this, SIGNAL(sigBgModeChanged(QString)), painter, SLOT(changeState(QString)));
 }
 
 MainWindow::~MainWindow()
@@ -295,14 +297,26 @@ void MainWindow::showColorDialog() {
     }
 }
 
-void MainWindow::changeEvent(QEvent *e)
-{
-    QMainWindow::changeEvent(e);
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        ui->retranslateUi(this);
-        break;
-    default:
-        break;
+bool MainWindow::event(QEvent *event) {
+    switch (event->type()) {
+        case QEvent::WindowActivate :
+            if (painter->bg_mode) {
+                emit sigBgModeChanged("bg_off");
+                painter->bg_mode = false;
+            }
+            return true;
+        case QEvent::WindowDeactivate :
+            if (!painter->bg_mode) {
+                emit sigBgModeChanged("bg_on");
+                painter->bg_mode = true;
+            }
+            return true;
+        default:
+            return QWidget::event(event);
     }
 }
+
+void MainWindow::changeEvent(QEvent *e)
+{
+
+}
