@@ -60,7 +60,8 @@ public:
 
 protected:
     void changeEvent(QEvent *e);
-    void closeEvent(QCloseEvent *);
+    void closeEvent(QCloseEvent *);   
+    bool event(QEvent *event);
 
 private:
     Ui::MainWindow *ui;
@@ -133,6 +134,9 @@ private slots:
     //! Sets Ice tool as current.
     void setIce();
     void showAbout(); /*! Shows about program dialog. */    
+
+signals:
+    void sigBgModeChanged(const QString &state);
 };
 
 #endif // MAINWINDOW_H
